==> model-1.2-sources.jar: org/ow2/weblab/core/model/ElementaryQuery.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * This kind of query is simply not a
 * 				ComposedQuery. It contains a weight (with default value at 1.0)
 * 				which could be used for Query combination. Data Exchange Model for
 * 				WebLab platform provided by CASSIDIAN Query package - Version 1.2 -
 * 				2010/08
 * 
 * <p>Java class for ElementaryQuery complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ElementaryQuery">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}Query">
 *       &lt;attribute name="weight" use="required" type="{http://www.w3.org/2001/XMLSchema}float" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ElementaryQuery")
@XmlSeeAlso({
    StringQuery.class,
    SimilarityQuery.class
})
public abstract class ElementaryQuery
    extends Query
    implements Serializable
{

    private final static long serialVersionUID = 12L;
    @XmlAttribute(required = true)
    protected float weight;

    /**
     * Gets the value of the weight property.
     * 
     */
    public float getWeight() {
        return weight;
    }

    /**
     * Sets the value of the weight property.
     * 
     */
    public void setWeight(float value) {
        this.weight = value;
    }

}

==> model-1.2.2-sources.jar: org/ow2/weblab/core/model/ElementaryQuery.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * This kind of Query is simply not a ComposedQuery. It contains a weight (with default value at 1.0) which could be used for Query 
 *             combination.
 * 
 * 
 * 				Data Exchange Model for WebLab platform provided by CASSIDIAN Version 1.2.1 - 2011/05
 * 
 * <p>Java class for ElementaryQuery complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ElementaryQuery">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}Query">
 *       &lt;attribute name="weight" use="required" type="{http://www.w3.org/2001/XMLSchema}float" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ElementaryQuery")
@XmlSeeAlso({
    StringQuery.class,
    SimilarityQuery.class
})
public abstract class ElementaryQuery
    extends Query
    implements Serializable
{

    private final static long serialVersionUID = 121L;
    @XmlAttribute(name = "weight", required = true)
    protected float weight;

    /**
     * Gets the value of the weight property.
     * 
     */
    public float getWeight() {
        return weight;
    }

    /**
     * Sets the value of the weight property.
     * 
     */
    public void setWeight(float value) {
        this.weight = value;
    }

}
